.. _material_opt_src:

material_opt.py
---------------

:download:`Download the file. </../sfepy/examples/homogenization/material_opt.py>`

.. literalinclude:: /../sfepy/examples/homogenization/material_opt.py
